deviceInfo = {
    "GUNNARP panel round": {"Color_space": "WS"},
    "LEPTITER Recessed spot light": {"Color_space": "WS"},
}
